Struct Rid
pub struct Rid(String);Expand description
Restriction identifier (RFC 8851).
Used in “Simulcast” to label different encodings of the same source (e.g. “low” and “high” resolution). Unlike SSRC which is a random number that can change if a collision occurs, RID is a stable string label.
Tuple Fields
0: StringImplementations